@@ -21,6 +21,8 @@
 
 #include "config.h"
 
+#include <glib/gi18n.h>
+
 #include "spelling-checker.h"
 #include "spelling-dictionary.h"
 #include "spelling-init.h"
@@ -39,15 +41,25 @@ _spelling_init (void)
 
   if (g_once_init_enter (&initialized))
     {
+      bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+      bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
+
       g_type_ensure (SPELLING_TYPE_CHECKER);
       g_type_ensure (SPELLING_TYPE_DICTIONARY);
       g_type_ensure (SPELLING_TYPE_LANGUAGE);
       g_type_ensure (SPELLING_TYPE_PROVIDER);
       g_type_ensure (SPELLING_TYPE_TEXT_BUFFER_ADAPTER);
+
       g_once_init_leave (&initialized, TRUE);
     }
 }
 
+/**
+ * spelling_init:
+ *
+ * Call this function before using any other libspelling functions in your
+ * applications. It will initialize everything needed to operate the library.
+ */
 void
 spelling_init (void)
 {
